#
# spec file for package systemtap-docs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           systemtap-docs
Version:        5.2
Release:        1.2
Summary:        Documents and examples for systemtap
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
URL:            https://sourceware.org/systemtap/
Source0:        https://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz
Source1:        https://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz.asc
Source2:        systemtap.keyring
Source3:        README-BEFORE-ADDING-PATCHES
Source4:        README-KEYRING
Patch1:         systemtap-docdir-fix.diff
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig(json-c)
# for documents
BuildRequires:  fop
BuildRequires:  gcc-c++
BuildRequires:  latex2html
BuildRequires:  libdw-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  texlive-amsfonts
BuildRequires:  texlive-babel-english
BuildRequires:  texlive-collection-fontsrecommended
BuildRequires:  texlive-metafont-bin
BuildRequires:  xmlto
BuildRequires:  pkgconfig(libdebuginfod)
BuildRequires:  tex(charter.sty)
BuildRequires:  tex(fancybox.sty)
BuildRequires:  tex(fancyhdr.sty)
BuildRequires:  tex(fancyvrb.sty)
BuildRequires:  tex(float.sty)
BuildRequires:  tex(fullpage.sty)
BuildArch:      noarch

%description
SystemTap is an instrumentation system for systems running Linux.
This package contains the documents and examples for systemtap.

%prep
%setup -q -n systemtap-%{version}
%autopatch -p1

%build
# fix interpreter
find testsuite examples -name "*.stp" | xargs -n1 sed -i -e 's, /bin/env, %{_bindir}/env,'
find testsuite examples -type f | xargs chmod 644
autoreconf -fi
%configure --docdir=%{_docdir}/systemtap --disable-nls --with-python3
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags} doc
# COPYING packaged by main spec
cp README AUTHORS NEWS %{buildroot}%{_docdir}/systemtap/
# remove binaries and runtime stuff
rm -rf %{buildroot}%{_bindir}
rm -rf %{buildroot}%{_sbindir}
rm -rf %{buildroot}%{_prefix}/lib*
rm -rf %{buildroot}%{_libexecdir}
rm -rf %{buildroot}%{_datadir}/systemtap
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}%{_sysconfdir}
rm -rf %{buildroot}%{_unitdir}
# these man pages are in each sub package
rm -rf %{buildroot}%{_mandir}/man[178]
rm -rf %{buildroot}%{_mandir}/cs/man[178]

%files
%defattr(-,root,root)
%doc %{_docdir}/systemtap
%{_mandir}/man3/*
%{_mandir}/cs/man3/*

%changelog
* Mon Feb 24 2025 Tony Jones <tonyj@suse.com>
- Upgrade to version 5.2. See systemtap.changes for changelog
* Mon Jan  6 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Avoid usage of %%{_libdir} in a noarch package: noarch cannot rely
  on libdir, an arch-dependent variable. Rather use %%{_prefix}/lib*
  to remove files. Fixes build with RPM 4.20.
* Mon Jun 17 2024 Tony Jones <tonyj@suse.com>
- Upgrade to version 5.1. See systemtap.changes for changelog
* Sat Dec 30 2023 Florian "sp1rit" <sp1rit@disroot.org>
- Upgrade to version 5.0. See systemtap.changed for changelog
* Tue Sep 13 2022 Tony Jones <tonyj@suse.com>
- Upgrade to version 4.7. See systemtap.spec for changelog
* Thu Jan 27 2022 Tony Jones <tonyj@suse.com>
- Upgrade to version 4.6. See systemtap.spec for changelog
* Fri Dec  6 2019 Tony Jones <tonyj@suse.com>
- Upgrade to version 4.2. See systemtap.spec for changelog
* Fri Aug  9 2019 Tony Jones <tonyj@suse.com>
- Upgrade to version 4.1. See systemtap.spec for changelog
- Remove systemtap-exporter files (built due to BuildRequires: python3-devel)
* Fri Aug  3 2018 sschricker@suse.de
- Upgrade to version 3.3:
  Changelog: https://lwn.net/Articles/757030/
  eBPF backend extensions, easier access to examples, adapting to
  meltdown/spectre complications, real-time / high-cpu-count
  concurrency fixes
- Added public key of "Frank Ch. Eigler <fche@elastic.org>",
  since he signed the new package
* Fri Feb  2 2018 tonyj@suse.com
- Fix python3 build failures
* Mon Nov 20 2017 tonyj@suse.com
- Upgrade to version 3.2. See systemtap.spec for changelog
  Drop patch: systemtap-doc-back-down-gettext-version.diff
* Tue Mar 28 2017 jeffm@suse.com
- Update to version 3.1. See systemtap.spec for changelog
  Added patch: systemtap-doc-back-down-gettext-version.diff
* Fri Apr  1 2016 tonyj@suse.com
- Update to version 3.0. See systemtap.spec for changelog
  Drop patch: systemtap-xmlto-fop.diff
* Tue Nov 10 2015 tonyj@suse.com
- Update to version 2.9. See systemtap.spec for changelog
* Fri Sep 11 2015 tonyj@suse.com
- Update to version 2.8. See systemtap.spec for changelog
  Update patch 'systemtap-docdir-fix.diff' (package beginners guide)
* Fri Mar 27 2015 p.drouand@gmail.com
- Update to version 2.7. See systemtap.spec for changelog
- Update systemtap-docdir-fix.diff
* Tue Feb 17 2015 mpluskal@suse.com
- Add gpg signature and keyring
- Cleanup spec file with spec-cleaner
* Tue Sep  9 2014 tonyj@suse.com
- Update to version 2.6. See systemtap.spec for changelog
* Fri May  2 2014 tonyj@suse.com
- Update to version 2.5. See systemtap.spec for changelog
- Drop patch: langref.tex-add-option-to-babel-setup.patch (upstream)
- Patch systemtap-docs-autoconf-version.diff was still present
  despite being "dropped" in 2.4,  really delete it
* Thu Dec 19 2013 tonyj@suse.com
- Fix build errors due to changes in LaTeX packaging
- Add patch 'langref.tex-add-option-to-babel-setup.patch'
* Fri Nov 15 2013 tonyj@suse.com
- Update to version 2.4. See systemtap.spec for changelog
- Drop patch systemtap-docs-autoconf-version.diff
* Wed Aug  7 2013 tonyj@suse.com
- Update to version 2.3. See systemtap.spec for changelog
* Wed May 22 2013 tonyj@suse.com
- Update to version 2.2.1. See systemtap.spec for changelog
* Sat Jan 12 2013 tonyj@suse.com
- Update to version 2.0. See systemtap.spec for changelog
* Fri Jul 27 2012 aj@suse.de
- Fix build with glibc 2.16
* Mon Jun 18 2012 jslaby@suse.de
- Upgrade to version 1.8
* Thu Jun 14 2012 dimstar@opensuse.org
- Add systemtap-automake112.patch: Fix build with automake 1.12:
  + Support for automatic de-ANSI-fication has been removed.
  + Patch taken from upstream, git commit id 5b2bc70.
* Sat Feb 18 2012 tonyj@suse.com
- Update to version 1.7.  See systemtap.spec for changelog
* Sun Jan 29 2012 coolo@suse.com
- add automake too
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed Nov  2 2011 jslaby@suse.de
- update to 1.6
* Tue Jun  7 2011 coolo@novell.com
- fix file dependencies of examples and testsuite
* Tue May 17 2011 jslaby@suse.de
- fix gcc 4.6 build
* Fri Jan 21 2011 tonyj@novell.com
- Update to version 1.4. See systemtap.changes for full changelog.
* Thu Aug 26 2010 tonyj@novell.com
- Update to version 1.3
* Thu Mar 11 2010 tonyj@novell.com
- Update to version 1.1. See systemtap.changes for full changelog.
* Wed Dec  2 2009 tonyj@novell.com
- Minor changes to spec file
* Fri Oct  2 2009 tonyj@suse.de
- updated to version 1.0.  See systemtap.changes for full changelog.
* Tue Jul 21 2009 tiwai@suse.de
- corrected to use libexecdir
- fix summary and description
* Thu Jun 18 2009 tiwai@suse.de
- change to noarch
* Tue Jun 16 2009 tiwai@suse.de
- updated to version 0.9.8:
  * Module signing support
  * Debuginfo suggestions when a script fails
  * Using %%M in print formats for hex dumps can now print entire
    buffers
  * Dwarfless syscalls: The nd_syscalls tapset is now available to
    probe system calls without requiring kernel debug info.
  * sid() returns the session ID of the current process
  * stringat() indexes a single character from a string.
  * New script examples
* Fri May 22 2009 tiwai@suse.de
- add missing examples installation in docs subpackage
* Wed May 20 2009 tiwai@suse.de
- split docs and examples to docs subpackage and generate from its
  own spec file to cut off the dependency loop
* Fri May 15 2009 tiwai@suse.de
- split to several subpackages, systemtap-runtime, -client, -server
  and -sdt-devel (bnc#503088).
* Fri May  8 2009 tiwai@suse.de
- updated to released version 0.9.7:
  * Lots of fixes, improvements, see NEWS file for details
* Thu Feb 19 2009 tiwai@suse.de
- updated to systemtap snashot 20090214:
  * Version bump to 0.8
  * Bunch of fixes and updates, see ChangeLog
  * Fix for recent 2.6.29 kernels
- fixed doc build, using fop instead of direct xmlto pdf
* Thu Feb 12 2009 tiwai@suse.de
- backport the blacklist additions from upstream to fix possible
  system crash (bnc#459387, bnc#473277)
* Thu Feb  5 2009 tiwai@suse.de
- Backport tapset/signal.stp to fix the signal probe problem
  (bnc#468321)
* Tue Feb  3 2009 tiwai@suse.de
- Fix debugpath.exp with $SYSTEMTAP_DEBUGINFO_PATH (bnc#471811)
* Thu Jan 29 2009 tiwai@suse.de
- Fix procfs dir_entry count warning (bnc#470526)
- Improve the parsing of lineno checks (bnc#468247)
* Thu Jan 15 2009 tiwai@suse.de
- Fix quoting in Tcl scripts (bnc#461588)
* Mon Jan 12 2009 tiwai@suse.de
- Fix syntax errors with Tcl send_log (bnc#460886)
* Thu Dec 18 2008 tiwai@suse.de
- Fix stap failures with signal tapsets (bnc#459387)
* Tue Dec 16 2008 tiwai@suse.de
- Fix dependency on libebl1 (bnc#448331, #445783)
- Fix stap for 2.6.28 kernels
* Fri Dec 12 2008 tiwai@suse.de
- Don't assert of dwarf_getsrcfiles().  This hits recent SUSE
  kernels (bnc#455992)
- Backport fix patches for stap-*-server scripts to run with
  netcat (bnc#446686)
* Mon Dec  8 2008 tiwai@suse.de
- fixed unresolved path in man pages (bnc#457217)
- fixed build for old distros on OBS
* Thu Dec  4 2008 tiwai@suse.de
- fix ioblock.stp for SUSE 2.6.27.x kernel (bnc#456175)
* Fri Nov 21 2008 tiwai@suse.de
- Add the bound check of parameters to fix segfault (bnc#447551)
* Tue Nov  4 2008 tiwai@suse.de
- Fix systemtap assertion with CONFIG_RELOCATABLE (bnc#440351)
* Thu Sep 11 2008 tiwai@suse.de
- updated to snapshot 20080906
  * Fix / clean up autotools stuff
  * Ugly workaround for 2.6.27 and later kernel
  * stap-server updates
  * Lots of small fixes
* Tue Aug 12 2008 tiwai@suse.de
- updated to snapshot 20080809
  * bump to 0.7.1
  * tutorials
  * examples
  * i386-fix merged
  * previous patches are all merged in
- add latex2html to buildrequires for generating documents
* Fri Jun 20 2008 tiwai@suse.de
- fix run on i386 (bnc#401970)
- don't include obsolete linux/compile.h.
* Wed Jun 18 2008 tiwai@suse.de
- updated to snapshot 20080614:
  * bump to version 0.7, man page updates, misc fixes
    see ChangeLog for details
* Fri Mar 14 2008 tiwai@suse.de
- updated to snapshot 20080308:
  * configure fixes, compile option changes
  * fixes for 2.6.25 kernel
* Wed Jan 30 2008 tiwai@suse.de
- updated to snapshot 20080126
  * fix configure and automake stuff
  * gcc 4.3 fix is included
  * ufprobes fixes, improvements
  * reorganized probe condition implementation.
* Fri Jan 11 2008 tiwai@suse.de
- updated to snapshot 20080105
- fixed build of the snapshot with gcc 4.3
* Mon Nov 19 2007 tiwai@suse.de
- enable gcc-4.3 patch (yes, we use only gcc4.3 now)
- updated to snapshot 20071117
* Thu Oct 25 2007 tiwai@suse.de
- disable gcc-4.3 fix again since it breaks older gccs...
* Wed Oct 24 2007 tiwai@suse.de
- fix build with gcc 4.3
* Mon Oct 22 2007 tiwai@suse.de
- updated to snapshot 20071020:
  * bump up version 0.6
  * bunch of updates and fixes, see ChangeLog
* Tue Aug 14 2007 tiwai@suse.de
- updated to snapshot 20070811:
  * Updated -m MODNAME usage
  * Rework on line editing functions
* Mon Jul 16 2007 tiwai@suse.de
- updated to snapshot 20070714:
  * configure fix for sqlite
  * support for crash extension module
  * new enum for type column in coverage_element
* Wed Jul  4 2007 tiwai@suse.de
- updated to snapshot 20070630:
  * auto-tools fixes, sqlite3 requirement
- add sqlite-devel and glib2-devel to buildrequires
* Wed Jun  6 2007 tiwai@suse.de
- updated to snapshot 20070602:
  * fix for gcc4.3
  * minor fixes in elaborate.*
- include the snapshot date into version string
- clean up spec file
* Tue May 22 2007 tiwai@suse.de
- updated to snapshot 20070519:
  * Updated temporary handlings
  * Autoconf tweaks
  * Performance improvements with const and temporary handlings
  * Removed do_write and do_read probles, added aio_write,
    aio_read, writev and readv probes.
* Mon May 21 2007 tiwai@suse.de
- use the external elfutils packages.
* Tue Apr 24 2007 tiwai@suse.de
- updated to snapshot 20070421 and elfutils-0.127:
  * minor compile warning fixes
  * add interruptible parameter
  * improvement on documents
  * fix for debugfs and relayfs mounts
  * see ChangeLog for other changes
* Mon Mar 19 2007 tiwai@suse.de
- updated to snapshot 20070317:
  including all fix patches
* Thu Mar  8 2007 tiwai@suse.de
- fix the handling of function arguments in more generic way
  (#245310, #252311)
  added a new option -P to switch the prologue-search behavior
* Wed Mar  7 2007 tiwai@suse.de
- fix misalignment of exception table entry on s390x (#249576)
* Mon Feb 26 2007 tiwai@suse.de
- fix crash with large H value in hist_linear() (#248430)
* Fri Feb 23 2007 tiwai@suse.de
- fix mmap syscall on s390x (#248110)
* Thu Feb 15 2007 tiwai@suse.de
- fix a wrong name of store_deref definition (#245544)
* Wed Feb 14 2007 tiwai@suse.de
- fix the handling of function arguments on s390x (#245310)
* Tue Feb  6 2007 tiwai@suse.de
- update to snapshot 20070203, bugfixes including:
  * add missing sockets tapset support (#239346)
  * fix the array membership (#242481)
* Wed Jan 31 2007 tiwai@suse.de
- turn on Autoprov again to fix broken dependency.
* Tue Jan 30 2007 tiwai@suse.de
- update to snapshot 20070120 and elfutils-0.125 to fix major
  bugs (#238710):
  * fixed libdw known bugs in elfutils 0.124
  * add the missing support of tapsetr/errno.stp for s390x
  * fix conditionals in syscall tapset for s390x
  * new macros to safely read/write values from kernel pointers
  * fix the non-standard C behavior to handle NULL in an array
  * fixed support for benchmarking mode with off-line code
  * added support to allow user to use array size declarations
  * reduce number of calls to stp_module_relocate within $tvar
    functions
* Tue Jan  9 2007 tiwai@suse.de
- updated to the recent snapshot version (FATE 301670).
  * fix cache bugs
  * auto-tools fixes
  * probe registartion rework
  * allow negative numeric literals
  * bugfixes/optmizations
- elfutls 1.2.4
  removed codes with problematic license in elfutils (#232894)
* Thu Aug 24 2006 tiwai@suse.de
- update elfutils to 1.2.3, including vmlinux.debuginfo fix.
* Thu Aug 24 2006 tiwai@suse.de
- fix the auto-lookup of vmlinux debuginfo for SUSE systems
- fix the stp compilation with 2.6.18 kernel
* Wed Aug  9 2006 tiwai@suse.de
- updated to latest snapshot (version 0.5.8)
  with elfutils-1.2.2.
* Tue Apr 18 2006 mason@suse.de
- Update to latest snapshot
* Sun Apr  9 2006 mason@suse.de
- created package
